/* This is the primary Elementary header file that includes all other useful
 * headers.
 * 
 * Elementary is distributed under the LGPLv2 license. Please see the COPYING
 * file that was distributed with this source.
 */
#ifndef ELEMENTARY_H
#define ELEMENTARY_H

#define ELM_UNIX
#undef ELM_WIN32
#undef ELM_WINCE
#undef ELM_EDBUS
#undef ELM_EFREET
#undef ELM_ETHUMB
#undef ELM_WEB
#undef ELM_EMAP
#undef ELM_DEBUG
#define ELM_ALLOCA_H
#define ELM_LIBINTL_H
#define ELM_DIRENT_H

/* Standard headers for standard system calls etc. */
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <sys/time.h>
#include <sys/param.h>
#include <math.h>
#include <fnmatch.h>
#include <limits.h>
#include <ctype.h>
#include <time.h>
#ifdef ELM_DIRENT_H
#include <dirent.h>
#endif
#include <pwd.h>
#include <errno.h>

#ifdef ELM_UNIX
#include <locale.h>
#ifdef ELM_LIBINTL_H
#include <libintl.h>
#endif
#include <signal.h>
#include <grp.h>
#include <glob.h>
#endif

#ifdef ELM_ALLOCA_H
#include <alloca.h>
#endif

#if defined (ELM_WIN32) || defined (ELM_WINCE)
#include <malloc.h>
#ifndef alloca
#define alloca _alloca
#endif
#endif

/* EFL headers */
#include <Eina.h>
#include <Eet.h>
#include <Evas.h>
#include <Evas_GL.h>
#include <Ecore.h>
#include <Ecore_Evas.h>
#include <Ecore_File.h>
#include <Ecore_IMF.h>
#include <Ecore_Con.h>
#include <Edje.h>

#ifdef ELM_EDBUS
#include <E_DBus.h>
#endif

#ifdef ELM_EFREET
#include <Efreet.h>
#include <Efreet_Mime.h>
#include <Efreet_Trash.h>
#endif

#ifdef ELM_ETHUMB
#include <Ethumb_Client.h>
#endif

#ifdef ELM_EMAP
#include <EMap.h>
#endif

#ifdef EAPI
# undef EAPI
#endif

#ifdef _WIN32
# ifdef ELEMENTARY_BUILD
#  ifdef DLL_EXPORT
#   define EAPI __declspec(dllexport)
#  else
#   define EAPI
#  endif /* ! DLL_EXPORT */
# else
#  define EAPI __declspec(dllimport)
# endif /* ! EFL_EVAS_BUILD */
#else
# ifdef __GNUC__
#  if __GNUC__ >= 4
#   define EAPI __attribute__ ((visibility("default")))
#  else
#   define EAPI
#  endif
# else
#  define EAPI
# endif
#endif /* ! _WIN32 */

#ifdef _WIN32
# define EAPI_MAIN
#else
# define EAPI_MAIN EAPI
#endif

/* allow usage from c++ */
#ifdef __cplusplus
extern "C"
{
#endif

/* docs */
#include <elm_intro.h> // OK
#include <elm_getting_started.h> // OK
#include <elm_authors.h> // OK

#define ELM_VERSION_MAJOR 1
#define ELM_VERSION_MINOR 0

typedef struct _Elm_Version
{
   int major;
   int minor;
   int micro;
   int revision;
} Elm_Version;

EAPI extern Elm_Version *elm_version;

/* include these first for general used definitions */
#include <elm_general.h> // OK
#include <elm_tooltip.h> // OK
#include <elm_object_item.h> // OK

/* special widgets - types used elsewhere */
#include <elm_icon.h> // OK
#include <elm_scroller.h> // OK
#include <elm_entry.h> // OK
#include <elm_list.h> // OK

/* other includes */
// Tom Hacohen
#include <elc_ctxpopup.h> // OK
#include <elc_dayselector.h> // OK
#include <elc_fileselector_button.h> // OK
#include <elc_fileselector_entry.h> // OK
#include <elc_fileselector.h> // OK
#include <elc_hoversel.h> // OK
#include <elc_multibuttonentry.h> // OK
#include <elc_naviframe.h> // OK
#include <elc_popup.h> // OK
#include <elm_actionslider.h> // OK
#include <elm_app.h> // OK
#include <elm_bg.h> // OK
#include <elm_box.h> // OK

// Daniel Juyung Seo
#include <elm_bubble.h> // OK
#include <elm_button.h> // OK
#include <elm_cache.h> // OK
#include <elm_calendar.h> // OK
#include <elm_check.h> // OK
#include <elm_clock.h> // OK
#include <elm_cnp.h> // OK
#include <elm_colorselector.h> // OK
#include <elm_config.h> // OK
#include <elm_conform.h> // OK
#include <elm_cursor.h> // OK
#include <elm_datetime.h> // OK
#include <elm_debug.h> // OK
#include <elm_diskselector.h> // OK

// Chuneon Park
//#include <elm_factory.h>  // OK
#include <elm_finger.h> // OK
#include <elm_flip.h> // OK
#include <elm_flipselector.h> // OK
#include <elm_focus.h>  // OK
#include <elm_font.h> // OK
#include <elm_frame.h> // OK
#include <elm_gen.h> // OK
#include <elm_gengrid.h> // OK
#include <elm_genlist.h> // OK
#include <elm_gesture_layer.h> // OK
#include <elm_glview.h> // OK
#include <elm_grid.h> // OK

// Woohyun Jung
#include <elm_hover.h> // OK
#include <elm_image.h> // OK
#include <elm_index.h> // OK
#include <elm_label.h> // OK
#include <elm_layout.h> // OK
#include <elm_macros.h> // OK
#include <elm_mapbuf.h> // OK
#include <elm_map.h> // OK
#include <elm_menu.h> // OK
#include <elm_mirroring.h> // OK
#include <elm_need.h> // OK
#include <elm_notify.h> // OK
#include <elm_object.h> // OK

// SanjeevBA
#include <elm_panel.h> // OK
#include <elm_panes.h> // OK
#include <elm_photocam.h> // OK
#include <elm_photo.h> // OK
#include <elm_plug.h> // OK
#include <elm_progressbar.h> // OK
#include <elm_radio.h> // OK
#include <elm_route.h> // OK
#include <elm_scale.h> // OK
#include <elm_scroll.h> // OK
#include <elm_segment_control.h> // OK

// Carsten Haitzler
#include <elm_separator.h> // OK
#include <elm_slider.h> // OK
#include <elm_slideshow.h> // OK
#include <elm_spinner.h> // OK
#include <elm_store.h> // OK
#include <elm_table.h> // OK
#include <elm_theme.h> // OK
#include <elm_thumb.h> // OK
#include <elm_toolbar.h> // OK
#include <elm_transit.h> // OK
#include <elm_video.h> // OK
#include <elm_web.h>
#include <elm_win.h> // OK

/* include deprecated calls last of all */
#include <elm_deprecated.h> // OK

#ifdef __cplusplus
}
#endif

#endif
